﻿using System;
using System.Globalization;
using System.Windows.Data;
using System.Windows.Media;

namespace TestProject
{
    /// <summary>
    /// RGB↔Color 값 변환자
    /// </summary>
    public class RGBToColorValueConverter : IMultiValueConverter
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 변환하기 - Convert(valueArray, targetType, parameter, cultureInfo)

        /// <summary>
        /// 변환하기
        /// </summary>
        /// <param name="valueArray">값 배열</param>
        /// <param name="targetType">타겟 타입</param>
        /// <param name="parameter">매개 변수</param>
        /// <param name="cultureInfo">문화 정보</param>
        /// <returns>변환 값</returns>
        public object Convert(object[] valueArray, Type targetType, object parameter, CultureInfo cultureInfo)
        {
            Color color = Color.FromRgb
            (
                (byte)(double)valueArray[0],
                (byte)(double)valueArray[1],
                (byte)(double)valueArray[2]
            );

            if(targetType == typeof(Color))
            {
                return color;
            }

            if(targetType == typeof(Brush))
            {
                return new SolidColorBrush(color);
            }

            return null;
        }

        #endregion
        #region 역변환하기 - ConvertBack(value, targetTypeArray, parameter, cultureInfo)

        /// <summary>
        /// 역변환하기
        /// </summary>
        /// <param name="value">값</param>
        /// <param name="targetTypeArray">타겟 타입 배열</param>
        /// <param name="parameter">매개 변수</param>
        /// <param name="cultureInfo">문화 정보</param>
        /// <returns>역변환 값</returns>
        public object[] ConvertBack(object value, Type[] targetTypeArray, object parameter, CultureInfo cultureInfo)
        {
            Color color;

            if(value is Color)
            {
                color = (Color)value;
            }
            else if(value is SolidColorBrush)
            {
                color = (value as SolidColorBrush).Color;
            }
            else
            {
                return null;
            }

            object[] primaryValueArray = new object[3];

            primaryValueArray[0] = color.R;
            primaryValueArray[1] = color.G;
            primaryValueArray[2] = color.B;

            return primaryValueArray;
        }

        #endregion
    }
}